@@ -2,6 +2,9 @@
  *
  * Copyright (C) 2003  Peter Hanappe and others.
  *
+ * SoundFont file loading code borrowed from Smurf SoundFont Editor
+ * Copyright (C) 1999-2001 Josh Green
+ *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public License
  * as published by the Free Software Foundation; either version 2 of
@@ -313,6 +316,7 @@ int fluid_defsfont_load(fluid_defsfont_t* sfont, const char* file)
       return FLUID_FAILED;
     }
     fluid_defsfont_add_sample(sfont, sample);
+    fluid_voice_optimize_sample(sample);
     p = fluid_list_next(p);
   }
 
@@ -1384,7 +1388,6 @@ fluid_inst_zone_import_sfont(fluid_inst_zone_t* zone, SFZone *sfzone, fluid_defs
       FLUID_LOG(FLUID_ERR, "Couldn't find sample name");
       return FLUID_FAILED;
     }
-    fluid_voice_optimize_sample(zone->sample);
   }
 
   /* Import the modulators (only SF2.1 and higher) */
@@ -1606,7 +1609,7 @@ fluid_sample_import_sfont(fluid_sample_t* sample, SFSample* sfsample, fluid_defs
     sample->valid = 0;
     FLUID_LOG(FLUID_WARN, "Ignoring sample %s: can't use ROM samples", sample->name);
   }
-  if (sample->end - sample->start < 48) {
+  if (sample->end - sample->start < 8) {
     sample->valid = 0;
     FLUID_LOG(FLUID_WARN, "Ignoring sample %s: too few sample data points", sample->name);
   } else {
@@ -1632,7 +1635,9 @@ fluid_sample_import_sfont(fluid_sample_t* sample, SFSample* sfsample, fluid_defs
 
 
 
-/*=================================sfload.c========================*/
+/*=================================sfload.c========================
+  Borrowed from Smurf SoundFont Editor by Josh Green
+  =================================================================*/
 
 /*
    functions for loading data from sfont files, with appropriate byte swapping
@@ -2967,7 +2972,9 @@ fixup_sample (SFData * sf)
   return (OK);
 }
 
-/*=================================sfont.c========================*/
+/*=================================sfont.c========================
+  Smurf SoundFont Editor
+  ================================================================*/
 
 
 /* optimum chunk area sizes (could be more optimum) */
